AndroidTVRemote class

Constructors

AndroidTVRemote()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

connect({required String host, required int port, required String pkcs12Path, String password = ''}) Future<bool>
disconnect() Future<void>
generateCertificates() Future<Map>
sendCommand(String command) Future<bool>
sendPin(String pin) Future<bool>
startDiscovery({required dynamic onDevices(List<TVDevice>)}) Future<bool>
startPairing({required dynamic onPin(String), required dynamic onStatus(String)}) Future<bool>

Constants

channel → const MethodChannel