TVDevice class

Constructors

TVDevice({required String name, required String hostname, required String ipAddress, required int port})
TVDevice.fromMap(Map map)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
hostname → String
final
ipAddress → String
final
name → String
final
port → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited